# coding: utf-8

# flake8: noqa

"""
    SatNOGS DB

    SatNOGS DB is a transmitter suggestions and crowd-sourcing app.  # noqa: E501

    The version of the OpenAPI document: 1
    Contact: dev@satnogs.org
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from satnogsdbapiclient.api.default_api import DefaultApi

# import ApiClient
from satnogsdbapiclient.api_client import ApiClient
from satnogsdbapiclient.configuration import Configuration
from satnogsdbapiclient.exceptions import OpenApiException
from satnogsdbapiclient.exceptions import ApiTypeError
from satnogsdbapiclient.exceptions import ApiValueError
from satnogsdbapiclient.exceptions import ApiKeyError
from satnogsdbapiclient.exceptions import ApiAttributeError
from satnogsdbapiclient.exceptions import ApiException
# import models into sdk package
from satnogsdbapiclient.models.inline_response200 import InlineResponse200
from satnogsdbapiclient.models.inline_response2001 import InlineResponse2001

