# coding: utf-8

"""
    SatNOGS DB

    SatNOGS DB is a transmitter suggestions and crowd-sourcing app.  # noqa: E501

    The version of the OpenAPI document: 1
    Contact: dev@satnogs.org
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import satnogsdbapiclient
from satnogsdbapiclient.api.default_api import DefaultApi  # noqa: E501
from satnogsdbapiclient.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = satnogsdbapiclient.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_artifact(self):
        """Test case for create_artifact

        """
        pass

    def test_create_demod_data(self):
        """Test case for create_demod_data

        """
        pass

    def test_list_artifacts(self):
        """Test case for list_artifacts

        """
        pass

    def test_list_demod_datas(self):
        """Test case for list_demod_datas

        """
        pass

    def test_list_latest_tle_sets(self):
        """Test case for list_latest_tle_sets

        """
        pass

    def test_list_modes(self):
        """Test case for list_modes

        """
        pass

    def test_list_satellites(self):
        """Test case for list_satellites

        """
        pass

    def test_list_transmitters(self):
        """Test case for list_transmitters

        """
        pass

    def test_retrieve_artifact(self):
        """Test case for retrieve_artifact

        """
        pass

    def test_retrieve_demod_data(self):
        """Test case for retrieve_demod_data

        """
        pass

    def test_retrieve_latest_tle_set(self):
        """Test case for retrieve_latest_tle_set

        """
        pass

    def test_retrieve_mode(self):
        """Test case for retrieve_mode

        """
        pass

    def test_retrieve_satellite(self):
        """Test case for retrieve_satellite

        """
        pass

    def test_retrieve_transmitter(self):
        """Test case for retrieve_transmitter

        """
        pass


if __name__ == '__main__':
    unittest.main()
